@@ -15,12 +15,12 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package WebService::Pixabay;
-$WebService::Pixabay::VERSION = '2.2.0';
+$WebService::Pixabay::VERSION = '2.2.1';
 # ABSTRACT: Perl 5 interface to Pixabay API.
 
 use strict;
 use warnings;
-use v5.10;
+use feature 'say';
 
 use Moo;
 use Function::Parameters;
@@ -103,27 +103,27 @@ WebService::Pixabay - Perl 5 interface to Pixabay API.
 
 =head1 VERSION
 
-version 2.2.0
+version 2.2.1
 
 =head1 SYNOPSIS
 
     use strict;
     use warnings;
     use v5.10;
-    
+
     use WebService::Pixabay;
     use Data::Dumper 'Dumper';
-    
+
     my $pix = WebService::Pixabay->new(api_key => 'secret');
-    
+
     # default searches
     my $img1 = $pix->image_search;
     my $vid1 = $pix->video_search;
-    
+
     # print data structure using Data::Dumper's 'Dumper'
     say Dumper($img1);
     say Dumper($vid1);
-    
+
     ###################################################
     # The parameters of the method have the same name #
     # and default values as in Pixabay API docs       #
@@ -161,13 +161,13 @@ version 2.2.0
     # Handling specific hashes and arrays of values from the image_search JSON
     # example retrieving webformatURL from each arrays
     my @urls = undef;
-    
+
     foreach my $url (@{$cust_img->{hits}}) {
 
         # now has link of photo urls (non-preview photos)
-        push(@urls, $url->{webformatURL});      
+        push(@urls, $url->{webformatURL});
     }
-    
+
     say $urls[3]; # image URL in the fourth row
 
     # Getting a specific single hash or array value from video_search JSON
@@ -197,10 +197,10 @@ version 2.2.0
 Description: Get image search metadata with default values as shown above.
 
 Parameter: q str A URL encoded search term. If omitted, all images are returned.
- This value may not exceed 100 characters. 
+ This value may not exceed 100 characters.
  Example: "yellow+flower"
 
-Parameter: lang str Language code of the language to be searched in. 
+Parameter: lang str Language code of the language to be searched in.
  Accepted values: cs, da, de, en, es, fr, id, it, hu, nl, no, pl, pt, ro, sk, fi, sv, tr, vi, th, bg, ru, el, ja, ko, zh
  Default: "en"
 
@@ -250,7 +250,7 @@ Parameter: callback string JSONP callback function name
 
 Parameter: pretty bool Indent JSON output. This option should not be used in production.
  Accepted values: "true", "false"
- Default: "false" 
+ Default: "false"
 
 Returns: Image search metadata.
 
@@ -277,10 +277,10 @@ Returns: Image search metadata.
 Description: Get video search metadata with default values as shown above.
 
 Parameter: q str A URL encoded search term. If omitted, all images are returned.
- This value may not exceed 100 characters. 
+ This value may not exceed 100 characters.
  Example: "yellow+flower"
 
-Parameter: lang str Language code of the language to be searched in. 
+Parameter: lang str Language code of the language to be searched in.
  Accepted values: cs, da, de, en, es, fr, id, it, hu, nl, no, pl, pt, ro, sk, fi, sv, tr, vi, th, bg, ru, el, ja, ko, zh
  Default: "en"
 
@@ -288,7 +288,7 @@ Parameter: id str ID, hash ID, or a comma separated list of values for retrievin
 
 Parameter: video_type str Filter results by video type.
  Accepted values: "all", "film", "animation"
- Default: "all" 
+ Default: "all"
 
 Parameter: orientation str Whether an image is wider than it is tall, or taller than it is wide.
  Accepted values: "all", "horizontal", "vertical"
@@ -326,12 +326,23 @@ Parameter: callback string JSONP callback function name
 
 Parameter: pretty bool Indent JSON output. This option should not be used in production.
  Accepted values: "true", "false"
- Default: "false" 
+ Default: "false"
 
 Returns: Video search metadata.
 
 =back
 
+=begin html
+
+
+
+
+=end html
+
+<a href="https://kritika.io/users/faraco/repos/3011578832649479/heads/master">
+<img src="https://kritika.io/users/faraco/repos/3011578832649479/heads/master/status.svg"/>
+</a>
+
 =head1 SEE ALSO
 
 L<Pixabay API documentations|https://pixabay.com/api/docs>
